ams.routines.routine
====================

.. automodule:: ams.routines.routine

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      collect_data
      initialize_data_dict
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      RoutineBase
   
   

   
   
   



